summaryrefslogtreecommitdiffstats
path: root/quanta/treeviews/templatestreeview.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:16:01 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:16:01 -0600
commit9771f17f8cc5252b12ec5f3edf47ff9bffdf997f (patch)
treeb9e389db87bdba126010d03fb5bccdc748d0e6fa /quanta/treeviews/templatestreeview.h
parent9930e16dde86b7de9b792613d826f4f8648b9768 (diff)
downloadtdewebdev-9771f17f8cc5252b12ec5f3edf47ff9bffdf997f.tar.gz
tdewebdev-9771f17f8cc5252b12ec5f3edf47ff9bffdf997f.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'quanta/treeviews/templatestreeview.h')
-rw-r--r--quanta/treeviews/templatestreeview.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/quanta/treeviews/templatestreeview.h b/quanta/treeviews/templatestreeview.h
index 075c9ba7..22fd3535 100644
--- a/quanta/treeviews/templatestreeview.h
+++ b/quanta/treeviews/templatestreeview.h
@@ -22,7 +22,7 @@
//forward declarations
class QuantaPropertiesPage;
-class KMainWindow;
+class TDEMainWindow;
class TemplatesTreeBranch : public BaseTreeBranch {
@@ -49,7 +49,7 @@ public:
* the parameter are only used at the first call to create the class
*
*/
- static TemplatesTreeView* const ref(KMainWindow *parent = 0L, const char *name = 0L)
+ static TemplatesTreeView* const ref(TDEMainWindow *parent = 0L, const char *name = 0L)
{
static TemplatesTreeView *m_ref;
if (!m_ref) m_ref = new TemplatesTreeView (parent, name);
@@ -74,14 +74,14 @@ public slots:
* displays the RBM
*
*
* @param listView KListView where the event comes from
*
* @param item TQListViewItem where the mousepointer is hovering
*
* @param point TQPoint coordinates of the event
*
*/
- void slotMenu(KListView *listView, TQListViewItem *item, const TQPoint &point);
+ void slotMenu(TDEListView *listView, TQListViewItem *item, const TQPoint &point);
/** Creates a new document based in the selected template. */
void slotNewDocument();
/** Insert the template as text, image, new document. */
@@ -119,7 +119,7 @@ private:
* If you need the class use TemplatesTreeView::ref() for
* construction and reference
*/
- TemplatesTreeView(KMainWindow *parent, const char *name = 0L);
+ TemplatesTreeView(TDEMainWindow *parent, const char *name = 0L);
/** Filters the template through and action, and returns the modified/filtered
template file */
KURL filterTemplate();
@@ -135,10 +135,10 @@ private:
TQString m_projectName;
KURL localURL;
KURL globalURL;
- KPopupMenu *m_fileMenu;
- KPopupMenu *m_folderMenu;
- KPopupMenu *m_emptyAreaMenu;
- KMainWindow *m_mainWindow;
+ TDEPopupMenu *m_fileMenu;
+ TDEPopupMenu *m_folderMenu;
+ TDEPopupMenu *m_emptyAreaMenu;
+ TDEMainWindow *m_mainWindow;
DirInfo m_dirInfo;
DirInfo m_parentDirInfo;
int m_insertFileInProject;
@@ -74,14 +74,14 @@ public slots:
*
*
- * @param listView KListView where the event comes from
+ * @param listView TDEListView where the event comes from
*
* @param item TQListViewItem where the mousepointer is hovering